library test.decoding;

import 'package:test/test.dart';
import 'package:jaguar_jwt/jaguar_jwt.dart';

final key = 'secret';

main() {
  group('Decoding', () {
    test('Nopayload', () {
      final String token =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhdWQiOlsiYWRtaW4iLCJzdHVkZW50cyJdLCJleHAiOjg2NDAwLCJpYXQiOiIyMDE2LTEyLTE2VDAwOjAwOjAwLjAwMCIsImlzcyI6InRlamEiLCJzdWIiOiIxMjM0NTY3ODkwIn0=.udEDnUW199M3jlm_bl0BqSADGEFE1TeeV5Jh26vMvQM=';

      final JwtClaim claimSet = verifyJwtHS256Signature(token, key);

      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.subject, "1234567890");
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, isEmpty);
      expect(claimSet.issuedAt,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000));
      expect(
          claimSet.expiry,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000)
              .add(new Duration(days: 1)));
    });

    test('With payload', () {
      String token =
          r'eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJhdWQiOlsiYWRtaW4iLCJzdHVkZW50cyJdLCJleHAiOjg2NDAwLCJpYXQiOiIyMDE2LTEyLTE2VDAwOjAwOjAwLjAwMCIsImlzcyI6InRlamEiLCJwbGQiOnsiayI6InYifSwic3ViIjoiMTIzNDU2Nzg5MCJ9.hilXwGlJ5xMRQ7vTsCHiBwHRa-9xVb4NEqDg4Ufsui0=';
      final JwtClaim claimSet = verifyJwtHS256Signature(token, key);
      expect(claimSet.issuer, equals('teja'));
      expect(claimSet.audience, equals(["admin", "students"]));
      expect(claimSet.payload, equals({"k": "v"}));
      expect(claimSet.subject, "1234567890");
      expect(claimSet.issuedAt,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000));
      expect(
          claimSet.expiry,
          new DateTime.fromMillisecondsSinceEpoch(1481842800000)
              .add(new Duration(days: 1)));
    });
  });
}
